require 'spec_helper'
require 'fileutils'

describe Deanswerify::Parser do
  describe "#strip_answers" do
    it "should remove all text within a single multiline answer block" do
      expected = File.read(File.join(File.dirname(__FILE__), 'fixtures/files_solution/block_single.js'))
      input = File.read(File.join(File.dirname(__FILE__), 'fixtures/files/block_single.js'))
      parsed = Deanswerify::Parser.strip_answers(input)

      expect(parsed).to eq(expected)
    end

    it "should remove all text within multiple multiline answer blocks" do
      expected = File.read(File.join(File.dirname(__FILE__), 'fixtures/files_solution/block_multiple.js'))
      input = File.read(File.join(File.dirname(__FILE__), 'fixtures/files/block_multiple.js'))
      parsed = Deanswerify::Parser.strip_answers(input)

      expect(parsed).to eq(expected)
    end

    it "should remove all text within a single inline answer block" do
      expected = File.read(File.join(File.dirname(__FILE__), 'fixtures/files_solution/inline_single.js'))
      input = File.read(File.join(File.dirname(__FILE__), 'fixtures/files/inline_single.js'))
      parsed = Deanswerify::Parser.strip_answers(input)

      expect(parsed).to eq(expected)
    end

    it "should remove all text within multiple inline answer blocks" do
      expected = File.read(File.join(File.dirname(__FILE__), 'fixtures/files_solution/inline_multiple.js'))
      input = File.read(File.join(File.dirname(__FILE__), 'fixtures/files/inline_multiple.js'))
      parsed = Deanswerify::Parser.strip_answers(input)

      expect(parsed).to eq(expected)
    end

    it "should not alter a file that is unchanged by the regex" do
      expected = File.read(File.join(File.dirname(__FILE__), 'fixtures/files_solution/no_change.md'))
      input = File.read(File.join(File.dirname(__FILE__), 'fixtures/files/no_change.md'))
      parsed = Deanswerify::Parser.strip_answers(input)

      expect(parsed).to eq(expected)
    end
  end
end
